@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-08-19'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2015-09-11'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,9 +38,12 @@ has extra_urls_for_version => (is=>'rw');
 has config_filename => (is=>'rw');
 has ssl_verify_hostname => (is=>'rw');
 has load_modules => (is=>'rw');
-has snippet_before_instantiate_cmdline => (is=>'rw');
+has code_before_instantiate_cmdline => (is=>'rw');
+has code_after_end => (is=>'rw');
 has skip_format => (is=>'rw');
 
+sub mvp_multivalue_args { qw(code_before_instantiate_cmdline code_after_end) }
+
 sub gather_files {
     # we actually don't generate scripts in this phase but in the later stage
     # (FileMunger) to be able to get more built version of modules. we become
@@ -110,6 +113,11 @@ sub munge_files {
             }
         }
 
+        my $code_before_instantiate_cmdline = $self->code_before_instantiate_cmdline;
+        if (ref($code_before_instantiate_cmdline) eq 'ARRAY') { $code_before_instantiate_cmdline = join("\n", @$code_before_instantiate_cmdline) }
+        my $code_after_end = $self->code_after_end;
+        if (ref($code_after_end) eq 'ARRAY') { $code_after_end = join("\n", @$code_after_end) }
+
         $res = gen_perinci_cmdline_script(
             url => $self->url,
             script_name => $scriptname,
@@ -122,7 +130,8 @@ sub munge_files {
             cmdline => $self->cmdline,
             prefer_lite => $self->prefer_lite,
             ssl_verify_hostname => $self->ssl_verify_hostname,
-            snippet_before_instantiate_cmdline => $self->snippet_before_instantiate_cmdline,
+            code_before_instantiate_cmdline => $code_before_instantiate_cmdline,
+            code_after_end => $code_after_end,
             config_filename => $self->config_filename,
             (subcommand => $subcommands) x !!$subcommands,
             subcommands_from_package_functions => $self->subcommands_from_package_functions,
@@ -209,7 +218,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.23 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-08-19.
+This document describes version 0.24 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-09-11.
 
 =head1 SYNOPSIS
 
@@ -349,9 +358,9 @@ This can be used if the Riap function URL is https and you don't want to verify.
 
 Comma-separated string, extra modules to load in the generated script.
 
-=head2 snippet_before_instantiate_cmdline => str
+=head2 code_before_instantiate_cmdline => str
 
-This is like the configuration, but per-script.
+=head2 code_after_end => str
 
 =head2 skip_format => bool
 
@@ -378,7 +387,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
 
 =head1 BUGS
 
